@@ -22,19 +22,14 @@ from polly.tracking import Track
 
 class Cohort:
     """
-    The Cohort class contains functions which can be used to create cohorts, add or remove samples,\
+    The Cohort class contains functions which can be used to create cohorts, add or remove samples, \
 merge metadata and data-matrix of samples/datasets in a cohort and edit or delete a cohort.
+Args:
+    token (str): token copy from polly
+Usage:
+    from polly.cohort import Cohort
 
-    ``Args:``
-        |  ``token (str):`` token copy from polly.
-
-    .. code::
-
-
-            from polly.cohort import Cohort
-            # To use this class initialize a object like this if you are not authorised on polly
-            cohort = Cohort(token)
-
+    cohort = Cohort(token)
     If you are authorised then you can initialize object without token to know about :ref:`authentication <auth>`.
     """
 
@@ -67,43 +62,22 @@ merge metadata and data-matrix of samples/datasets in a cohort and edit or delet
         sample_id=None,
     ) -> None:
         """
-            This function is used to create a cohort.
+        This function is used to create a cohort. After making Cohort Object you can create cohort.
 
-            ``Args:``
-                |  ``local_path(str):`` local path to instantiate the cohort.
-                |  ``cohort_name(str):`` identifier name for the cohort.
-                |  ``description(str):`` description about the cohort.
-                |  ``repo_key(str):`` Optional argument: repo_key(repo_name/repo_id) for the omixatlas from where \
-datasets or samples is to be added.
-                |  ``entity_id(list):`` Optional argument: list of dataset_id or sample_id to be added to the \
-cohort.
-
-            ``Returns:``
-                |  A confirmation message on creation of cohort.
-
-            ``Errors:``
-                |  ``InvalidParameterException:`` Empty or Invalid Parameters
-                |  ``InvalidCohortNameException:`` The cohort_name does not represent a valid cohort name.
-                |  ``InvalidPathException:`` Provided path does not represent a file or a directory.
-
-            | After making Cohort Object you can create cohort.
-            | Example-
-            | 1. while passing argument of repo and dataset.
-
-            .. code::
-
-
-                cohort.create_cohort("/import/tcga_cohort","cohort_name","cohort_description",\
-"repo_id",list_of_datasets)
-
-            | 2. without passing argument of repo and dataset.
-
-            .. code::
-
-
-                    cohort2.create_cohort("/path","cohort_name","cohort_description")
+        Args:
+              local_path (str): local path to instantiate the cohort.
+              cohort_name (str): identifier name for the cohort.
+              description (str): description about the cohort.
+              repo_key (str): repo_key(repo_name/repo_id) for the omixatlas from where datasets or samples is to be added.
+              entity_id (list): list of dataset_id or sample_id to be added to the cohort.
 
+        Returns:
+              A confirmation message on creation of cohort.
 
+        Raises:
+              InvalidParameterException: Empty or Invalid Parameters
+              InvalidCohortNameException: The cohort_name does not represent a valid cohort name.
+              InvalidPathException: Provided path does not represent a file or a directory.
         """
         self._cohort_path = self.bridge_obj.create_cohort(
             local_path, cohort_name, description
@@ -121,25 +95,16 @@ cohort.
         """
         This function is used to add datasets or samples to a cohort.
 
-        ``Args:``
-            |  ``repo_key(str):`` repo_key(repo_name OR repo_id) for the omixatlas where datasets or samples belong.
-            |  ``entity_id(list):`` list of dataset ID or sample ID to be added to the cohort.
+        Args:
+              repo_key (str): repo_key(repo_name OR repo_id) for the omixatlas where datasets or samples belong.
+              entity_id (list): list of dataset ID or sample ID to be added to the cohort.
 
-        ``Returns:``
-            |  A confirmation message for number of datasets or samples which are added to the cohort.
-
-        ``Errors:``
-            |  ``InvalidParameterException:`` Empty or Invalid Parameters.
-            |  ``InvalidCohortOperationException:`` This operation is not valid as no cohort has been \
-instantiated.
-
-        | After creating cohort we can add datasets or samples to cohort.
-        | Example-
-        .. code::
-
-
-                cohort.add_to_cohort("repo_id",list_of_dataset_ids)
+        Returns:
+              A confirmation message for number of datasets or samples which are added to the cohort.
 
+            Raises:
+              InvalidParameterException: Empty or Invalid Parameters.
+              InvalidCohortOperationException: This operation is not valid as no cohort has been instantiated.
         """
         self.bridge_obj._cohort_details = self._cohort_details
         if self._cohort_details is None:
@@ -175,24 +140,17 @@ instantiated.
     @Track.track_decorator
     def remove_from_cohort(self, dataset_id=None, sample_id=[]) -> None:
         """
-        This function is used for removing datasets or samples from a cohort.
+        TThis function is used for removing datasets or samples from a cohort.
 
-        ``Args:``
-            |  ``entity_id(list):`` list of dataset IDs or sample IDs which is to be removed from the cohort.
+        Args:
+              entity_id (list): list of dataset IDs or sample IDs which is to be removed from the cohort.
 
-        ``Returns:``
-            |  A confirmation message on removal of datasets or samples from cohort.
+        Returns:
+              A confirmation message on removal of datasets or samples from cohort.
 
-        ``Errors:``
-            |  ``InvalidParameterException:`` Empty or Invalid Parameters
-            |  ``InvalidCohortOperationException:`` This operation is not valid as no cohort has been \
-instantiated.
-
-        |  Example-
-        .. code::
-
-
-                cohort.remove_from_cohort(list_of_datasets)
+        Raises:
+              InvalidParameterException: Empty or Invalid Parameters
+              InvalidCohortOperationException: This operation is not valid as no cohort has been instantiated.
         """
         self.core_obj._cohort_details = self._cohort_details
         if self._cohort_details is None:
@@ -211,14 +169,13 @@ instantiated.
     @Track.track_decorator
     def merge_data(self, data_level: str):
         """
-        Function to merge metadata (dataset, sample and feature level metadata) or data-matrix of all the samples\
-or datasets in the cohort.
+        Function to merge metadata (dataset,sample and feature level) or data-matrix of all the samples/datasets in the cohort.
 
         Args:
-            | data_level(str): identifier to specify the data to be merged - "dataset", "sample", "feature" or \
-"data_matrix"
+                data_level (str): identifier to specify the data to be merged - "dataset", "sample", "feature" or "data_matrix"
+
         Returns:
-            | A pandas dataframe containing the merged data which is ready for analysis
+                A pandas dataframe containing the merged data which is ready for analysis
         """
         self.core_obj._cohort_details = self._cohort_details
         if self._cohort_details is None:
@@ -267,18 +224,12 @@ or datasets in the cohort.
         """
         This function is used to check the validity of a cohort.
 
-        ``Returns:``
-            |  A boolean result based on the validity of the cohort.
+        Returns:
+                A boolean result based on the validity of the cohort.
 
-        ``Errors:``
-            |  ``InvalidPathException:`` Cohort path does not represent a file or a directory.
-            |  ``InvalidCohortOperationException:`` This operation is not valid as no cohort has been \
-instantiated.
-
-        .. code::
-
-
-                cohort2.is_valid()
+        Raises:
+                InvalidPathException: Cohort path does not represent a file or a directory.
+                InvalidCohortOperationException: This operation is not valid as no cohort has been instantiated.
         """
         self.core_obj._cohort_details = self._cohort_details
         if self._cohort_details is None:
@@ -339,23 +290,17 @@ instantiated.
 
     def load_cohort(self, local_path: str):
         """
-        Function to load an existing cohort into an object. Once loaded, the functions described in the \
-documentation can be used for the object where the cohort is loaded.
+        Function to load an existing cohort into an object.
+        Once loaded, the functions described in the documentation can be used for the object where the cohort is loaded.
 
-        ``Args:``
-            |  ``local_path(str):`` local path of the cohort.
+        Args:
+                    local_path (str): local path of the cohort.
 
-        ``Returns:``
-            |  A confirmation message on instantiation of the cohort.
-
-        ``Errors:``
-            |  ``InvalidPathException:`` This path does not represent a file or a directory.
-            |  ``InvalidCohortPathException:`` This path does not represent a Cohort.
-
-        |  Example-
-        .. code::
-
-                cohort.load_cohort("/path/cohort_name.pco")
+        Returns:
+                    A confirmation message on instantiation of the cohort.
+        Raises:
+                    InvalidPathException: This path does not represent a file or a directory.
+                    InvalidCohortPathException: This path does not represent a Cohort.
 
         """
         self.core_obj.load_cohort(local_path)
@@ -364,26 +309,17 @@ documentation can be used for the object where the cohort is loaded.
 
     def edit_cohort(self, new_cohort_name=None, new_description=None):
         """
-          This function is used to edit the cohort level metadata such as cohort name and description.
+        This function is used to edit the cohort level metadata such as cohort name and description.
+        Args:
+                    new_cohort_name (str): Optional Argument: new identifier name for the cohort.
+                    new_description (str): Optional Argument: new description about the cohort.
 
-        ``Args:``
-            |  ``new_cohort_name(str):`` Optional Argument: new identifier name for the cohort.
-            |  ``new_description(str):`` Optional Argument: new description about the cohort.
-
-        ``Returns:``
-            |  A confirmation message on updation of cohort.
-
-        ``Errors:``
-            |  ``InvalidCohortOperationException:`` This operation is not valid as no cohort has been \
-instantiated.
-            |  ``CohortEditException:`` No parameter specified for editing in cohort
-
-        |  Example-
-        .. code::
-
-
-                cohort.edit_cohort("edited-cohort-name","edited-cohort-description")
+            Returns:
+                    A confirmation message on updation of cohort.
 
+            Raises:
+                    InvalidCohortOperationException: This operation is not valid as no cohort has been instantiated.
+                    CohortEditException: No parameter specified for editing in cohort
         """
         self.core_obj._cohort_details = self._cohort_details
         if self._cohort_details is None:
@@ -401,42 +337,13 @@ instantiated.
         """
         Function to return cohort level metadata and dataframe with datasets or samples added in the cohort.
 
-        ``Returns:``
-            |  A tuple with the first value as cohort metadata information (name, description and number of \
-dataset(s) or sample(s) in the cohort) and the second value as dataframe containing the source, \
-dataset_id or sample_id and data type available in the cohort.
+        Returns:
+              A tuple with the first value as cohort metadata information
+              (name, description and number of dataset(s) or sample(s) in the cohort) and the second value
+              as dataframe containing the source, dataset_id/sample_id and data type available in the cohort.
 
-        ``Errors:``
-            |  ``InvalidCohortOperationException:`` This operation is not valid as no cohort has been \
-instantiated.
-
-        | Example-
-
-        .. code::
-
-
-                metadata, cohort_details = cohort.summarize_cohort()
-        | metadata will contain a object like this.
-
-        .. code::
-
-
-                {
-                'cohort_name': 'cohort_name',
-                'number_of_samples': 6,
-                'description': 'cohort_description'
-                }
-        | cohort detail will contain a table like that
-        .. csv-table::
-            :header: "", "source_omixatlas",  "datatype", "dataset_id"
-            :delim: |
-
-            0 |	tcga |	Mutation |	BRCA_Mutation_TCGA-A8-A09Q-01A-11W-A019-09
-            1 |	tcga |	Mutation |	BRCA_Mutation_TCGA-AN-A0FL-01A-11W-A050-09
-            2 |	tcga |	Mutation |	BRCA_Mutation_TCGA-AR-A254-01A-21D-A167-09
-            3 |	tcga |	Mutation |	BRCA_Mutation_TCGA-D8-A1XO-01A-11D-A14K-09
-            4 |	tcga |	Mutation |	BRCA_Mutation_TCGA-EW-A1J2-01A-21D-A13L-09
-            5 |	tcga |	Mutation |	BRCA_Mutation_TCGA-LL-A50Y-01A-11D-A25Q-09
+            Raises:
+              InvalidCohortOperationException: This operation is not valid as no cohort has been instantiated.
         """
         self.core_obj._cohort_details = self._cohort_details
         if self._cohort_details is None:
@@ -447,7 +354,7 @@ instantiated.
         """
         This function is used to delete a cohort.
         Returns:
-            | A confirmation message on deletion of cohort
+            A confirmation message on deletion of cohort
         """
         self.core_obj._cohort_details = self._cohort_details
         if self._cohort_details is None:
@@ -480,9 +387,9 @@ instantiated.
         """
           This function is used to merge all the gct files in a cohort into a single gct file.
 
-        ``Args:``
-            |  ``file_path(str):`` the system path where the gct file is to be written.
-            |  ``file_name(str):`` Optional Argument: Identifier for the merged file name, cohort name will be used by default.
+        Args:
+                    file_path (str): the system path where the gct file is to be written.
+                    file_name (str): Identifier for the merged file name, cohort name will be used by default.
         """
         self.core_obj._cohort_details = self._cohort_details
         if self._cohort_details is None:
