@@ -20,6 +20,8 @@ from polly.errors import (
     paramException,
     AccessDeniedError,
     InvalidRepoException,
+    DatatypeNotFoundException,
+    RepositoryNotFoundException,
 )
 from polly.constants import COHORT_CONSTANTS_URL, REPORT_FIELDS_URL, ELUCIDATA_LOGO_URL
 from bs4 import BeautifulSoup
@@ -458,12 +460,12 @@ def change_file_access(
     return final_url
 
 
-def get_user_details(self):
+def get_user_details(session, base_url):
     """
     Function to get user details
     """
-    me_url = f"{self.base_url}/users/me"
-    details = self.session.get(me_url)
+    me_url = f"{base_url}/users/me"
+    details = session.get(me_url)
     error_handler(details)
     user_details = details.json().get("data", {}).get("attributes")
     return user_details
@@ -659,7 +661,7 @@ def workspaces_permission_check(self, workspace_id) -> bool:
     permission_url = f"{self.base_url}/workspaces/{workspace_id}/permissions"
     response = self.session.get(permission_url, params={"include": "user"})
     error_handler(response)
-    user_details = get_user_details(self)
+    user_details = get_user_details(self.session, self.base_url)
     user_id = user_details.get("user_id")
     if "data" in response.json():
         json_data = response.json().get("data")
@@ -747,3 +749,52 @@ def parseInt(sin):
     m = re.search(r"^(\d+)[.,]?\d*?", str(sin))
     parsed_int = int(m.groups()[-1]) if m and not callable(sin) else None
     return parsed_int
+
+
+def replace_original_name_field(
+    dataset_source_info: dict,
+    schema_dict_val: dict,
+    dataset_source: str,
+    data_type: str,
+) -> dict:
+    """
+    Function to replace original name field for dataset metadata
+    Arguments:
+    dataset_source_info: dataset metadata to be updated
+    schema_dict_val: schema info for the datasets
+    repo_name: repository name
+    data_type: data_type of the dataset that is required
+    Checks for the following cases:
+    Case 1: The schema for the particular dataset has source as "all" and datatype as "all"
+    Case 2: The schema for the particular dataset has source as "all" and datatype as multiple datatypes
+    Case 3: The schema for the particular dataset has source as multiple repositories and datatype as "all"
+    Case 4: The schema for the particular dataset has source as multiple repositories and datatype as multiple datatypes
+    Currently only Case 1 is valid, but in future the other cases might arrive, hence incorporated the checks accordingly.
+    """
+    if "all" in schema_dict_val:
+        source_dict = schema_dict_val.get("all")
+        if "all" in source_dict:
+            schema_info = source_dict.get("all")
+        elif data_type in source_dict:
+            schema_info = source_dict.get(data_type)
+        else:
+            raise DatatypeNotFoundException(data_type)
+    elif dataset_source in schema_dict_val:
+        source_dict = schema_dict_val.get(dataset_source)
+        if "all" in source_dict:
+            schema_info = source_dict.get("all")
+        elif data_type in source_dict:
+            schema_info = source_dict.get(data_type)
+        else:
+            raise DatatypeNotFoundException(data_type)
+    else:
+        raise RepositoryNotFoundException(dataset_source)
+    replaced_metadata = {}
+    source_keys = dataset_source_info.keys()
+    for key in source_keys:
+        if key in schema_info:
+            original_name = schema_info.get(key).get("original_name")
+            replaced_metadata[original_name] = dataset_source_info.get(key)
+        else:
+            replaced_metadata[key] = dataset_source_info.get(key)
+    return replaced_metadata
